@@ -1,22 +1,30 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: newargs.c,v 2.7 2012-06-05 09:58:53 Gebruiker Exp $
+	$Id: newargs.c,v 2.8 2012-11-28 20:49:52 Gebruiker Exp $
 */
 
 #include	<stdio.h>
 
+#include	"sim.h"
 #include	"ForEachFile.h"
 #include	"Malloc.h"
 #include	"error.h"
 #include	"newargs.h"
 
 #define	ARGS_INCR	1024
-static char *args = 0;
-static int args_free = 0;
-static int args_size = 0;
+static char *args;
+static int args_free;
+static int args_size;
 
 static void
-add_to_args(char ch) {
+init_args(void) {
+	args = 0;
+	args_free = 0;
+	args_size = 0;
+}
+
+static void
+add_char_to_args(char ch) {
 	if (args_free == args_size) {
 		/* allocated array is full; increase its size */
 		int new_size = args_size + ARGS_INCR;
@@ -30,6 +38,14 @@ add_to_args(char ch) {
 	args[args_free++] = ch;
 }
 
+static void
+add_string_to_args(const Fchar *fn) {
+	while (*fn) {
+		add_char_to_args(*fn++);
+	}
+	add_char_to_args('\n');
+}
+
 static char *
 std_input(void) {
 	/* in the form (name \n)* \0 */
@@ -42,10 +58,10 @@ std_input(void) {
 		/* omit duplicate layout (= empty name) */
 		if (last_char == '\n' && ch == '\n') continue;
 
-		add_to_args(ch);
+		add_char_to_args(ch);
 		last_char = ch;
 	}
-	add_to_args('\0');
+	add_char_to_args('\0');
 
 	/* make sure the result conforms to the form above  */
 	if (args[args_free-2] != '\n')
@@ -93,6 +109,7 @@ new_argv(int argc, char *args) {
 
 void
 get_new_std_input_args(int *argcp, const char **argvp[]) {
+	init_args();
 	char *n_args = std_input();
 	int argc = n_names(n_args);
 	const char **argv = new_argv(argc, n_args);
@@ -108,12 +125,9 @@ register_file(const Fchar *fn, const char *msg, const struct stat *fs) {
 	}
 
 	if (	/* it is a non-empty regular file */
-	    S_ISREG(fs->st_mode) && fs->st_size > 0
+		S_ISREG(fs->st_mode) && fs->st_size > 0
 	) {
-		while (*fn) {
-			add_to_args(*fn++);
-		}
-		add_to_args('\n');
+		add_string_to_args(fn);
 	}
 }
 
@@ -126,16 +140,23 @@ recursive_args(int argc, const char *argv[]) {
 		int i;
 
 		for (i = 0; i < argc; i++) {
-			ForEachFile(str2Fname(argv[i]), register_file);
+			const char *arg = argv[i];
+			const Fchar *Farg = str2Fname(arg);
+			if (is_new_old_separator(arg)) {
+				add_string_to_args(Farg);
+			} else {
+				ForEachFile(Farg, register_file);
+			}
 		}
 	}
-	add_to_args('\0');
+	add_char_to_args('\0');
 
 	return args;
 }
 
 void
 get_new_recursive_args(int *argcp, const char **argvp[]) {
+	init_args();
 	char *n_args = recursive_args(*argcp, *argvp);
 	int argc = n_names(n_args);
 	const char **argv = new_argv(argc, n_args);
