@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: pass1.c,v 2.17 2012-05-16 07:56:06 Gebruiker Exp $
+	$Id: pass1.c,v 2.21 2012-11-28 20:49:52 Gebruiker Exp $
 */
 
 #include	<stdio.h>
@@ -9,8 +9,9 @@
 #include	"debug.par"
 #include	"sim.h"
 #include	"text.h"
+#include	"token.h"
 #include	"tokenarray.h"
-#include	"lex.h"
+#include	"lang.h"
 #include	"error.h"
 #include	"options.h"
 #include	"pass1.h"
@@ -44,7 +45,7 @@ Read_Input_Files(int argc, const char *argv[], int round) {
 		txt->tx_pos = 0;
 		txt->tx_start =
 		txt->tx_limit = Text_Length();
-		if (strcmp(fname, "/") == 0) {
+		if (is_new_old_separator(fname)) {
 			if (round == 1 && !is_set_option('T')) {
 				fprintf(Output_File, "separator\n");
 			}
@@ -72,7 +73,10 @@ Read_Input_Files(int argc, const char *argv[], int round) {
 			if (round == 1 && !is_set_option('T')) {
 				fprint_count(Output_File,
 					     txt->tx_limit - txt->tx_start,
-					     token_name);
+					     token_name
+				);
+				fprintf(Output_File, ", ");
+				fprint_count(Output_File, lex_nl_cnt-1, "line");
 				if (lex_non_ascii_cnt) {
 					fprintf(Output_File, ", ");
 					fprint_count(Output_File,
