@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: stream.c,v 2.9 2012-05-05 14:47:47 Gebruiker Exp $
+	$Id: stream.c,v 2.11 2012-06-08 16:04:29 Gebruiker Exp $
 */
 
 #include	<stdio.h>
@@ -8,8 +8,9 @@
 #include	<sys/stat.h>
 
 #include	"system.par"
+#include	"sim.h"
+#include	"options.h"
 #include	"token.h"
-#include	"lex.h"
 #include	"lang.h"
 #include	"stream.h"
 
@@ -34,7 +35,8 @@ Open_Stream(const char *fname) {
 	return ok;
 }
 
-static FILE *fopen_regular_file(const char *fname) {
+static FILE *
+fopen_regular_file(const char *fname) {
 	struct stat buf;
 
 	if (stat(fname, &buf) != 0) return 0;
@@ -54,3 +56,36 @@ Close_Stream(void) {
 		yyin = 0;
 	}
 }
+
+void
+Print_Stream(const char *fname) {
+	fprintf(Output_File, "File %s:", fname);
+	if (!Open_Stream(fname)) {
+		fprintf(Output_File, " cannot open\n");
+		return;
+	}
+
+	if (!is_set_option('T')) {
+		fprintf(Output_File,
+			" showing token stream:\nnl_cnt, tk_cnt: %ss",
+			token_name
+		);
+
+		lex_token = End_Of_Line;
+		do {
+			if (Token_EQ(lex_token, End_Of_Line)) {
+				fprintf(Output_File, "\n%u,%u:",
+					lex_nl_cnt, lex_tk_cnt
+				);
+			}
+			else {
+				fprintf(Output_File, " ");
+				fprint_token(Output_File, lex_token);
+			}
+		} while (Next_Stream_Token_Obtained());
+
+		fprintf(Output_File, "\n");
+	}
+
+	Close_Stream();
+}
